// Cleans the raw IPUMS data and brings it to a form that absmob.ado can use
// Needs to be run only once.

****EDIT THESE GLOBALS TO REFLECT YOUR LOCAL DIRECTORIES***
global rawdataroot  "" //Path to folder containing downloaded data from IPUMS (See data_raw in README)
global intermedroot "" //Path to folder that will contain the cleaned data (See data_clean in README)
*-------------------------------------------------------*

local mtr_in_file "$intermedroot/NTR_cleaned.csv"
local mtr_out_file "$intermedroot/nominal_tax_rates"

// * Years for which Census and CPS analyses are to be run */
local census_start = 1940
local census_end   = 2010
local cps_start    = 1970
local cps_end      = 2014
	
local adjust_1940		true //Imputes non-wage income data to the raw 1940 Census data 
local clean_census 		true //Clean raw Census data -- no rows are dropped.
local clean_cps 		true //Clean raw CPS data and undo topcoding -- no rows are dropped.
local reshape_census 	true //reshape each census file to produce 2 files -- couples and families
local reshape_cps 		true //reshape CPS data to produce a couples file
local reshape_mtr 		true //fixes an MTR file -- adds variables used by absmob

*The locals below are used only if gen_rep_parents is true
local partype richer //The type of representative parent. One of richer | older | mother | father
local pargender		//Restrict to parents of this gender. male | female | <blank>

global exclude_gq match_cps //alternatively, "all" or "none"
set more off

if "`adjust_1940'" == "true" {
	
	use "$rawdataroot/Census1950_raw", clear
	sort serial pernum 
	
	replace incwage   = . if incwage   == 999999
	replace inctot    = . if inctot    == 9999999
	replace ftotinc   = . if ftotinc   == 9999999 | ftotinc == 9999998
	
	// many cases where ftotinc is missing but inctot is not
	replace ftotinc   = inctot if ftotinc == .
	
	// we need both family income and wages to compute nonwage income
	keep if ftotinc != . & incwage != .
	keep if ftotinc >= 0
	
	gen nonwage = .
	replace nonwage = ftotinc if ftotinc != .
	replace nonwage = nonwage - incwage if nonwage != . & incwage != .
	//replace nonwage = nonwage - fwage2 if fwage2 !=. 
	
	/* Deflate 1949 to 1939 Dollars, using CPI
	http://data.bls.gov/cgi-bin/cpicalc.pl?cost1=1&year1=1949&year2=1939  */
	replace nonwage = nonwage * 0.58 
	
	replace occ1950 = . if occ1950 == 999 | occ1950 == 997
	replace race = 3 if race >= 3
	
	gen incnonwg = .
	replace incnonwg = 1 if nonwage >= 0  & nonwage <= 50 & nonwage != .
	replace incnonwg = 2 if nonwage >  50 & nonwage != .
	//imputation in 1940 is done only for people who indicated they had more than $50 in nonwage income  
	
	collapse (mean) nonwage, by(occ1950 classwkr race incnonwg)
	
	replace nonwage = round(nonwage)
	
	sort occ1950 classwkr race incnonwg
	
	tempfile inc_adj_for_1940
	save    `inc_adj_for_1940', replace 
	
	use "$rawdataroot/Census1940_raw", clear
	
	capture confirm v nonwage 
	if !_rc{
		drop nonwage
	} 
	
	replace occ1950 = . if occ1950 == 999 | occ1950 == 997
	replace race = 3 if race >= 3
	
	merge m:1 occ1950 classwkr race incnonwg using `inc_adj_for_1940'
	
	replace nonwage = .  if incnonwg==0 | incnonwg==. | occ1950==. 
	replace nonwage = 50 if incnonwg==1 & _merge==1
	
	drop _merge
	save "$rawdataroot/Census1940_raw", replace

}

if "`clean_census'" == "true" {

	foreach year of numlist `census_start'(10)`census_end' {
	
		cd "$rawdataroot"
		use Census`year'_raw, clear			
		
		drop if mi(year) | mi(pernum) | mi(serial) | mi(sex) | mi(age)
		
		if "$exclude_gq" == "all" {
			drop if gq > 1
		}
		else if "$exclude_gq" == "match_cps" {
		//drop institutional gq: institutions, correctional instit, mental instit, instit for elderly&handicapped&poor, military 
			drop if (gqtype == 1 | gqtype == 2 | gqtype == 3 | gqtype == 4 | gqtype == 6)
		}		
		
		foreach drop_var in datanum cluster strata related perwt gq gqtype {
			capture confirm var `drop_var' 
			if !_rc {
				drop `drop_var' 
			}
		}
		
		//If the following variables are absent, create them
		foreach required_var in inctot ftotinc incwelfr incsupp {
			capture confirm var `required_var'
			if _rc{
				gen double `required_var' = .				
			}
		}
				
		compress			
		replace incwage    = . if incwage   == 999999  | incwage   == 999998
		if `year' > 1940 {
			replace inctot    = . if inctot   == 9999999
			replace ftotinc   = . if ftotinc  == 9999999 | ftotinc == 9999998
		}

		if `year' > 1960 { 
			replace incwelfr    = . if incwelfr   == 99999				
		}

		if `year' > 1990 { 
			replace incsupp    = . if incsupp   == 99999				
		}
		
		* 2000 onward, INCSUPP is separated out from INCWELFR. To keep welfr consistent over time, we add it back.
		* See "comparability" section of INCWELFR on IPUMS
		if `year' >= 2000 {
			replace incwelfr = incwelfr + incsupp if !mi(incsupp)
		}
	
		gen long id = 100*serial + pernum
		sort year id
		compress

		cd "$intermedroot"
		save census`year'.dta, replace 
	}
}


if "`clean_cps'" == "true" {

	cd "$rawdataroot"

	u CPS_1968to2015.dta, clear
	merge 1:1 year serial pernum using cps_swapvalues, nogen

	local vlist incalim incaloth incasist incchild incdrt inceduc incgov incidr incint ///
		 incother incrent incss incssi incunemp incvet incwelfr incwkcom
	foreach var of varlist `vlist' {
		replace `var' = . if `var' == 99999
	}

	local vrbls incdisab incdivid inclongj incretir incsurv oincbus oincfarm ftotval
	foreach var of varlist `vrbls' {
		replace `var' = . if `var' == 999999
	}

	local vrs incbus incfarm incwage oincwage
	foreach var of varlist `vrs' {
			replace `var' = . if `var' == 9999999 | `var' == 9999998
		}
		
	replace inctot = . if inctot == 99999999 | inctot == 99999998	
	replace sploc = 0  if mi(sploc) | sploc < 0 //Never happens in the rawdata, but just in case.
	
	local vars incwage incbus incfarm incss incwelfr incgov incaloth incretir incssi incdrt ///
		incint incunemp incwkcom incvet incsurv incdisab incdivid incrent inceduc incchild incalim ///
		incasist incother inclongj oincbus oincfarm oincwage

	foreach var of varlist `vars' {
		replace `var' = `var'_swap if `var'_swap !=. & `var'_swap!=0 
	}

	// Pre 1988, inctot is the sum of the variables listed in `list87'. Post 1988, inctot is the sum of the variables in `list88'.
	local list75 incwage  incbus  incfarm  incss incwelfr incidr incaloth incgov 
	local list87 incwage  incbus  incfarm  incss incwelfr incretir incssi incint incdrt incaloth incgov
	local list88 oincwage oincbus oincfarm incss incwelfr incretir incssi incint inclongj incunemp ///
		incwkcom incvet incsurv incdisab incdivid incrent inceduc incchild incalim incasist incother
	egen inctotal75 = rowtotal(`list75') if year >= 1968 & year <= 1975
	egen inctotal87 = rowtotal(`list87') if year >= 1976 & year <= 1987
	egen inctotal88 = rowtotal(`list88') if year >= 1988 & year <= 2015
	egen inctot_no_top = rowtotal(inctotal75 inctotal87 inctotal88)
	rename inctot inctot_topcoded
	rename inctot_no_top inctot
	
	* 1976 onward, INCSSI is separated out from INCWELFR. To keep welfr consistent over time, we add ssi back.
	* See "comparability" section of INCWELFR on IPUMS CPS
	replace incwelfr = incwelfr + incssi if year >= 1976 & !mi(incssi)
	
	gen long id = 100*serial + pernum
	gen long mom_id = 100*serial + momloc if momloc!=. & momloc>0
	gen long pop_id = 100*serial + poploc if poploc!=. & poploc>0
	
	// IPUMS renamed weighting variables in 2018
	ren asecwt wtsupp 
	ren asecwth hwtsupp
	
	keep year id marst serial mom_id pop_id sploc wtsupp bpl age sex inctot inctot_topcoded ftotval incwage incwelfr incssi nchild famsize 
	compress

	cd "$intermedroot"
	save CPS_intermed, replace 
}	

if "`reshape_census'" == "true" {

	foreach year of numlist `census_start'(10)`census_end' {
	
		/* Reshape data into couples -- each row contains an individual and his/her spouse, if one exists*/

		cd "$intermedroot"
		use "census`year'.dta", clear
		keep if sploc==0
		sort year id
		tempfile census_singles
		save `census_singles'
		
		use "census`year'.dta", clear
		keep if sploc != . & sploc > 0
		gen long id_spouse = 100*serial + sploc
		rename id  ownid
		rename incwage incwage_spouse
		rename age     age_spouse
		rename sex     sex_spouse
		rename bpl	   bpl_spouse
		
		rename incwelfr incwelfr_spouse
		rename incsupp incsupp_spouse
		rename inctot  inctot_spouse
		
		keep year id_spouse age_spouse ownid sex_spouse bpl_spouse incwage_spouse incsupp_spouse inctot_spouse incwelfr_spouse 
		
		tempfile census_spouses
		save `census_spouses'

		use "census`year'.dta", clear
		rename id id_spouse
		sort year serial pernum

		merge 1:1 year id_spouse using `census_spouses', keep(match)
		drop _merge

		bysort serial: gen dup_tag = _n 
		keep if dup_tag == 1 | dup_tag == 3 | dup_tag == 5 | dup_tag==7 | dup_tag==9 //keep only one row per couple

		rename id_spouse id
		rename ownid     id_spouse

		append using `census_singles'
		sort year id
		
		capture confirm var nonwage
		if _rc{
			gen nonwage = .
		}
		
		compress
		save "census`year'_couples.dta", replace 
		

		/* Reshape into families */
		//TODO: assumes unique father => unique mother, and vice versa. Fix with a better merge.
		gen long id_father = 100*serial + poploc if poploc != . & poploc>0
		gen long id_mother = 100*serial + momloc if momloc != . & momloc>0
		gen long id_parent = id_mother if id_mother != .
		replace  id_parent = id_father if id_parent == .
		
		rename id id_child
		rename age age_child
		rename sex sex_child
		rename bpl bpl_child
		keep year id_parent id_child age_child sex_child bpl_child
		
		sort id_parent
		tempfile census_kids
		save `census_kids'

		use "census`year'_couples.dta", clear
		keep if nchild > 0 //TODO: This looks redundant
		gen long id_parent = .
		replace id_parent  = id 	 
		replace id_parent  = id_spouse if sex_spouse==2

		duplicates drop id_parent, force
		tempfile census_parents
		save `census_parents'
		
		use `census_kids', clear
		merge m:1 id_parent using `census_parents', keep(match) 
		drop _merge

		compress
		save "census`year'_families.dta", replace 
	}	
}

if "`gen_rep_parents'" == "true"{

	forval census_year = `census_start' (10) `census_end' {
			
		use "$intermedroot/census`census_year'_families.dta", clear 
		generate_rep_id "`partype'" "`pargender'" "`census_year'"			
		save "$absmob_outdir/census`census_year'_families_`partype'", replace
		
		use "$intermedroot/census`census_year'_couples.dta", clear
		generate_rep_id "`partype'" "`pargender'" "`census_year'"
		save "$absmob_outdir/census`census_year'_families_`partype'", replace

	}
}

if "`reshape_cps'" == "true" {
	cd "$intermedroot"
	use CPS_intermed, replace
	gen hasSpouse = (marst == 1) & (sploc != 0)
	
	/* Extract single people and put them aside for now*/
	keep if hasSpouse == 0
	sort year id
	tempfile cps_singles
	save `cps_singles'

	/* Extract married individuals and reshape them */
	use CPS_intermed, clear
	gen hasSpouse = (marst == 1) & (sploc != 0)
	keep if hasSpouse > 0
	gen double spouseid = 100*serial + sploc
	
	//TODO: Make this a list and a cleaner rename
	rename id ownid
	rename inctot inctot_spouse
	rename inctot_topcoded inctot_topcoded_spouse
	rename incwage incwage_spouse	
	rename incwelfr incwelfr_spouse
	rename incssi incssi_spouse
	rename age age_spouse
	rename sex sex_spouse
	rename bpl bpl_spouse

	bysort year serial: keep if _n==1
	keep year spouseid ownid age_spouse sex_spouse inctot_spouse incwage_spouse incwelfr_spouse incssi_spouse bpl_spouse 
	tempfile cps_spouses
	save `cps_spouses'

	
	use CPS_intermed, clear
	gen hasSpouse = (marst == 1) & (sploc != 0)
	keep if hasSpouse > 0
	rename id spouseid
	bysort year serial: keep if _n>1 

	merge 1:m year spouseid using `cps_spouses', assert(match master) keep(match)
	drop _merge
	rename spouseid id
	rename ownid id_spouse

	/* add singles back to reshaped couple data */
	append using `cps_singles'

	recode bpl 		  (9900=0)(nonm=1), gen(foreigner)
	recode bpl_spouse (9900=0)(nonm=1), gen(foreigner_spouse)	
	replace famsize = 1 //self
	replace famsize = famsize + 1 if hasSpouse > 0 //add one for spouse
	replace famsize = famsize + nchild if !mi(nchild) //add kids

	drop if ftotval == . & inctot == . & inctot_spouse == .

	keep year id marst nchild id_spouse mom_id pop_id sex sex_spouse age age_spouse foreigner foreigner_spouse famsize wtsupp ///
		ftotval inctot inctot_spouse incwage incwage_spouse incwelfr incwelfr_spouse incssi incssi_spouse  
	sort year id
	compress

	order year id marst id_spouse age age_spouse sex sex_spouse nchild ///
		ftotval inctot inctot_spouse incwage incwage_spouse incwelfr incwelfr_spouse ///
		incssi incssi_spouse foreigner foreigner_spouse famsize wtsupp mom_id pop_id
	save CPS_clean.dta, replace 
}

if "`reshape_mtr'" == "true" {
	
	*mtr_in_file is expected to contain year, mtr, cutoff (above which that MTR applies) and ftpye 
	insheet using "`mtr_in_file'", clear
	levelsof year, local(cohorts)

	sort year ftype cutoff
	by year ftype: gen cpdiff = cutoff[_n+1] - cutoff
	
	**This is the tax liability corresponding to this particular tax-bracket
	gen taxdiff = mtr * cpdiff / 100 
	replace taxdiff = 0 if mi(taxdiff)
	
	**This is the cumulative tax liability of anyone who earns within this tax bracket
	by year ftype: gen cumsum = sum(taxdiff)
	
	**The cumulative tax liability of anyone who earns below this tax bracket
	by year ftype: gen min_tax = cumsum[_n-1]
	replace min_tax = 0 if cutoff == 0
	label var mtr "Marginal Tax Rate"
	label var ftype "Tax filing type"
	label var min_tax "tax liability for income <= cutoff"
	label var cutoff "Cutoff above which the MTR applies"
	drop taxdiff cpdiff cumsum
	capture drop id	
	save "`mtr_out_file'", replace	
}
