/* Runs the code to produce the data sets needed for Fig 5 and appendix */
/* Note: relies on output from robustness.do, which must be run first */

* Edit these globals to reflect your local paths 
global rawdataroot "" //The path to the raw data directory (see indir_raw in README)
global absmob_indir  "" //The path to the cleaned data directory (see input_clean in README)
global absmob_resultsdir "" //The path to a local folder that will contain all the resulting datasets
global absmob_sourcesdir "" //The path to the folder containing the downloaded source code (e.g. sources.do)

discard
adopath + "$absmob_sourcesdir"
clear
set more off

* Make Counterfactuals directory
global cfacts $absmob_resultsdir/Counterfactuals

* Make the dir if it doesn't exist
confirmdir "$cfacts"
if _rc > 0 { // _rc >0 if it doesn't exist
	mkdir "$cfacts"
}

* Derivative globals
global results_baseline = "$absmob_resultsdir/Baseline"
global results_robustness = "$absmob_resultsdir/Robustness"
global absmob_outdir = "$cfacts"
	
cd $cfacts
clear
local type "png" // "wmf" "pdf"



***************************************************
* Do analysis using ado file and true 1940 and 1980 distributions
***************************************************

*Copy over par and kid marginals
copy $results_baseline/kid_marginal.dta $cfacts/kid_marginal.dta, replace
copy $results_baseline/par_marginal.dta $cfacts/par_marginal.dta, replace
copy par_marginal.dta par_marginal_obs.dta, replace
copy kid_marginal.dta kid_marginal_obs.dta, replace

*Generate combined marginal distributions 
use par_marginal, clear
merge 1:1 percentile cohort using kid_marginal , nogen assert(3)
save marginals, replace

*Make parent marginal for 1980 only*
use marginals, clear
keep if cohort == 1980

sort kid_inc
assert _n == percentile
keep par_inc percentile cohort
save par_marginal_1980, replace

*Compute observed mobility rate for 1980
absmob compute mob, cohorts(1980) copula("copula_base_adjusted")
copy absmob.dta absmob_1980obs.dta, replace

*Compute observed mobility rate for 1940
absmob compute mob, cohorts(1940) copula("copula_base_adjusted")
copy absmob.dta absmob_1940obs.dta, replace


************************************************************************* 
** First Counterfactual: Higher GDP growth, unequal distribution
** Apply 1980 income-GDP ratios to counterfactual economy that grew at 2.5% annually (compared to 1.47% in real life)
** Use GDP per working family - family with at least one member age 18-64
** Real GDP data from https://fred.stlouisfed.org/series/GDPCA
** Data on number of working families from IPUMS 1940, 1970, 1980, 2010 censuses.
*************************************************************************

* Bring in GDP data
import delimited "$absmob_indir/GDPCA.csv", encoding(ISO-8859-1) clear
gen year = year(date(date, "YMD"))

foreach yr in 1940 1950 1970 1980 2010{
	preserve
	keep if year == `yr'
	local gdptot`yr' = gdpca
	noi di `gdptot`yr''
	restore
	}


* Create counts of working families
use $rawdataroot/Census1940_raw_cf, clear
append using $rawdataroot/Census1950_raw_cf
append using $rawdataroot/Census1960_raw
append using $rawdataroot/Census1970_raw
append using $rawdataroot/Census1980_raw
append using $rawdataroot/Census1990_raw
append using $rawdataroot/Census2000_raw
append using $rawdataroot/Census2010_raw

* Now, count how many working-age families there are **
gen workingage = age >= 18 & age <= 64
egen workers = max(workingage), by(year serial famunit) 

gen famwork = hhwt * workers

drop if gq == 3 | gq == 4

bys year serial famunit: replace famwork = 0 if _n != 1

collapse (sum) famwork, by(year)

save workfam_counts, replace


* Make macros with counts of working families for each of the decades that we'll use
foreach yr in 1940 1950 1970 1980 2010 {

	preserve
	keep if year == `yr'
	local workfams`yr' = famwork
	noi di `workfams`yr''
	restore
	}

* GDP per working family
local gdpfw40 = `gdptot1940' / `workfams1940' * 1000000000
local gdpfw50 = `gdptot1950' / `workfams1950' * 1000000000
local gdpfw70 = `gdptot1970' / `workfams1970' * 1000000000
local gdpfw80 = `gdptot1980' / `workfams1980' * 1000000000
local gdpfw10 = `gdptot2010' / `workfams2010' * 1000000000
 
noi di `gdpfw40' //35058.359
noi di `gdpfw50' //50458.505
noi di `gdpfw70' //83021.55
noi di `gdpfw80' //87907.775
noi di `gdpfw10' //136198.28

* Make GDP numbers in hard code
clear
set obs 8
gen year = "1940"
gen gdpfw = `gdpfw40'
gen gdptot = `gdptot1940'
replace year = "1950" if _n == 2
replace gdpfw = `gdpfw50' if _n == 2
replace gdptot = `gdptot1950' if _n == 2
replace year = "1970" if _n == 3
replace gdpfw = `gdpfw70' if _n == 3
replace gdptot = `gdptot1970' if _n == 3
replace year = "1980" if _n == 4
replace gdpfw = `gdpfw80' if _n == 4
replace gdptot = `gdptot1980' if _n == 4
replace year = "2010" if _n == 5
replace gdpfw = `gdpfw10' if _n == 5
replace gdptot = `gdptot2010' if _n == 5
replace year = "2010_counterfact" if _n == 6
replace gdpfw = 1.025^30 * `gdpfw80' if _n == 6
replace gdptot = 1.025^30 * `gdpfw80' * `workfams2010' / 1000000000 if _n == 6
replace year = "1980-2010 observed change" if _n == 7 
replace gdpfw = `gdpfw10' - `gdpfw80' if _n == 7
replace gdptot = `gdptot2010' - `gdptot1980' if _n == 7
replace year = "1980-2010 counterfactual change" if _n == 8
replace gdpfw = 1.025^30 * `gdpfw80' - `gdpfw80' if _n == 8
replace gdptot = 1.025^30 * `gdpfw80' * `workfams2010' / 1000000000 - `gdptot1980' if _n == 8

save counterfactuals_gdpnums, replace

** Compute counterfactual kid income - kid inc / current GDP * hypothetical 2.5% growth * 1980 GDP
local g = 25

use marginals, clear
keep if cohort == 1980

local gr = `g' / 1000
noi di `gr'
gen kid_inc_grineq = kid_inc / `gdpfw10' * (1 + `gr')^30 * `gdpfw80'
drop kid_inc 
rename kid_inc_grineq kid_inc 

sort kid_inc
assert _n == percentile
save kid_marginal, replace
copy kid_marginal.dta kid_marginal_hh.dta, replace

** Make sure using 1980 par marginal
copy par_marginal_1980.dta par_marginal.dta, replace

*Run mobility with counterfactual income
absmob compute mob, cohorts(1980) copula("copula_base_adjusted") 
copy absmob.dta absmob_1980hh.dta, replace


*************************************************************************
** Second Counterfactual: More broadly shared growth 
** Calculate ratio of income to GDP per working family for 1940 cohort
** Then apply that ratio to observed GDP in 2010
*************************************************************************

** Get 1940 shares of GDP
use marginals, clear
keep if cohort == 1940
gen sh40 = kid_inc / `gdpfw70'
keep percentile sh40
tempfile sh40
save `sh40'

** Get 1980 marginal distributions
local max = 100
use marginals, clear
keep if cohort == 1980

** Merge on 1940 shares
merge 1:1 percentile using `sh40', assert(3) nogen

** Compute counterfactual 1980 kid income - 1940 kids share of 1970 GDP * 2010 GDP
gen kid_inc_shlowlow = sh40 * `gdpfw10'
drop kid_inc 
rename kid_inc_shlowlow kid_inc 

sort kid_inc
assert _n == percentile
keep kid_inc percentile cohort
save kid_marginal, replace
copy kid_marginal.dta kid_marginal_ll.dta, replace

** Make sure using 1980 par marginal
copy par_marginal_1980.dta par_marginal.dta, replace

*Run mobility with counterfactual income
absmob compute mob, cohorts(1980) copula("copula_base_adjusted") 
copy absmob.dta absmob_1980ll.dta, replace


*************************************************************************
** More broadly shared growth counterfactual but with CPS 30 year olds instead of full GDP
*************************************************************************

* Calculate total income in sample of 30 year olds
use marginals, clear
sum par_inc if cohort == 1940, d
local par40 = r(mean)
noi di `par40' //18894.79
sum kid_inc if cohort == 1940, d
local kid40 = r(mean)
noi di `kid40' //57369.3
noi di (`kid40'/`par40') ^ (1/30) //1.0377146 annual growth in CPS incomes for 1940 cohort
noi di (`kid40' - `par40') / `kid40' //.67064632 total growth from parents to kids 1940-1970

sum par_inc if cohort == 1980, d
local par80 = r(mean)
noi di `par80' //57058.23
sum kid_inc if cohort == 1980, d
local kid80 = r(mean)
noi di `kid80' //60307.29
noi di (`kid80'/`par80') ^ (1/30) //1.0018477 annual growth in CPS incomes for 1980 cohort
noi di (`kid80' - `par80') / `kid80' //.05387508 total growth from parents to kids 1980-2010

** Get 1940 shares of total 30-year-old income
use marginals, clear
keep if cohort == 1940
gen sh40 = kid_inc / `kid40'
keep percentile sh40
tempfile sh40
save `sh40'

** Get 1980 marginal distributions
local max = 100
use marginals, clear
keep if cohort == 1980

** Add in 1940 growthrates by percentile **
merge 1:1 percentile using `sh40', assert(3) nogen

** Compute counterfactual kid income: income / total 30-year-old income for 1940 * total 30-year-old income 2010
gen kid_inc_eqlow = sh40 * `kid80'
drop kid_inc 
rename kid_inc_eqlow kid_inc 

sort kid_inc
assert _n == percentile
keep kid_inc percentile cohort
save kid_marginal, replace
copy kid_marginal.dta kid_marginal_ll_samp30.dta, replace

** Make sure using 1980 par marginal
copy par_marginal_1980.dta par_marginal.dta, replace

*Run mobility with counterfactual income
absmob compute mob, cohorts(1980) copula("copula_base_adjusted") 
copy absmob.dta absmob_1980ll_samp30.dta, replace


*************************************************************************
** More broadly shared growth counterfactuals with full income from the CPS. 
*************************************************************************

* Get CPI-U-RS to inflate CPS incomes
use $absmob_indir/cpirs.dta, clear
sum rate if year == 1969
local cpi69 = r(mean)
noi di `cpi69'
sum rate if year == 1979
local cpi79 = r(mean)
noi di `cpi79'
sum rate if year == 2009
local cpi09 = r(mean)
noi di `cpi09'
sum rate if year == 2014
local cpi14 = r(mean)
noi di `cpi14'
sum rate if year == 1939
local cpi39 = r(mean)
noi di `cpi39'

* Get total CPS income per working-age family in 1970 and 2010
use $rawdataroot/CPS_1968to2015, clear
replace inctot = 0 if inctot == 99999999
gen inct = inctot
replace inct = inct * `cpi14' / `cpi69' if year == 1970
replace inct = inct * `cpi14' / `cpi09' if year == 2010

** Get total CPS income in 1970
sum inct [w=wtsupp] if wtsupp >= 0 & year == 1970, d
local cpstotinc70 = r(sum_w) * r(mean)
noi di `cpstotinc70'

** Get total CPS income in 2010
sum inct [w=wtsupp] if wtsupp >= 0 & year == 2010, d
local cpstotinc10 = r(sum_w) * r(mean)
noi di `cpstotinc10'

** Get count of working-age families in 1970 and 2010
gen workage = age >= 18 & age <=64
drop if gq == 2
egen workfam = max(workage), by(year serial famunit)
gen famwork = workfam * hwtsupp
bys year serial famunit: replace famwork = 0 if _n != 1
sum famwork if year == 1970, d
local cpstotfam70 = r(mean) * r(N)
noi di `cpstotfam70'
sum famwork if year == 2010, d
local cpstotfam10 = r(mean) * r(N)
noi di `cpstotfam10'

* Calculate income/working-age family
local cpsincwf70 = `cpstotinc70' / `cpstotfam70'
local cpsincwf10 = `cpstotinc10' / `cpstotfam10'
noi di `cpsincwf70'
noi di `cpsincwf10'

** Calculate 1940 share of total income
use marginals, clear
keep if cohort == 1940
gen sh40 = kid_inc / `cpsincwf70'
keep percentile sh40
tempfile sh40
save `sh40'

** Get 1980 marginal distributions
local max = 100
use marginals, clear
keep if cohort == 1980

** Add in 1940 income shares by percentile **
merge 1:1 percentile using `sh40', assert(3) nogen

** Compute counterfactual kid income: 1940 kid income (measured in 1970) / total CPS income in 1970 * total CPS income in 2010
gen kid_inc_eqlow = sh40 * `cpsincwf10'
drop kid_inc 
rename kid_inc_eqlow kid_inc 

sort kid_inc
assert _n == percentile
keep kid_inc percentile cohort
save kid_marginal, replace
copy kid_marginal.dta kid_marginal_ll_cpsincwf.dta, replace

** Make sure using 1980 par marginal
copy par_marginal_1980.dta par_marginal.dta, replace

*Run mobility with counterfactual income
absmob compute mob, cohorts(1980) copula("copula_base_adjusted") 
copy absmob.dta absmob_1980ll_cpsincwf.dta, replace


*************************************************************************
** Counterfactual growth rates 1-10% with observed 2010 income distribution
*************************************************************************

foreach g in 10 20 30 40 50 60 70 80 90 100 {

	** Compute counterfactual kid income - kid inc / 2010 GDP * hypothetical growth * 1980 GDP
	use marginals, clear
	keep if cohort == 1980

	local gr = `g' / 1000
	noi di `gr'
	gen kid_inc_grineq = kid_inc / `gdpfw10' * (1 + `gr')^30 * `gdpfw80'
	drop kid_inc 
	rename kid_inc_grineq kid_inc 
	
	sort kid_inc
	assert _n == percentile
	save kid_marginal, replace
	copy kid_marginal.dta kid_marginal_gr`g'.dta, replace

	** Make sure using 1980 par marginal
	copy par_marginal_1980.dta par_marginal.dta, replace

	*Run mobility with counterfactual income
	absmob compute mob, cohorts(1980) copula("copula_base_adjusted") 
	copy absmob.dta absmob_1980gr`g'.dta, replace
}



*************************************************************************
** Now do counterfactual copulas
*************************************************************************

* Make sure we're back to observed par and kid marginals
copy par_marginal_obs.dta par_marginal.dta, replace
copy kid_marginal_obs.dta kid_marginal.dta, replace

* Perfectly fluid copula
absmob compute mob, cohorts(1980) copula("copula_perfect_mobility") 
copy absmob.dta absmob_1980mob.dta, replace

* Perfectly static copula
absmob compute mob, cohorts(1980) copula("copula_perfect_immobility") 
copy absmob.dta absmob_1980imob.dta, replace

*************************************************************************
** Robustness check: Age 40
*************************************************************************

copy "$results_robustness/40 vs 40/kid_marginal.dta" $cfacts/kid_marginal.dta, replace
copy "$results_robustness/40 vs 40/par_marginal.dta" $cfacts/par_marginal.dta, replace
copy par_marginal.dta par_marginal_40.dta, replace
copy kid_marginal.dta kid_marginal_40.dta, replace

*Generate combined GDP-deflated marginal distributions 
use par_marginal_40, clear
merge 1:1 percentile cohort using kid_marginal_40 , nogen assert(3)
save marginals_40, replace 

*Make parent marginal for 1970 only
keep if cohort == 1970

sort kid_inc
assert _n == percentile
keep par_inc percentile cohort
save par_marginal_1970_40, replace

*Compute observed gdp-deflated mobility rate for 1970
absmob compute mob, cohorts(1970) copula("copula_base_adjusted")
copy absmob.dta absmob_197040.dta, replace

*Compute observed gdp-deflated mobility rate for 1940
absmob compute mob, cohorts(1940) copula("copula_base_adjusted")
copy absmob.dta absmob_194040.dta, replace

*************************************************************************
** Higher GDP growth counterfactual with age 40
*************************************************************************

use marginals_40, clear
keep if cohort == 1970

local g = 25
local gr = `g' / 1000
noi di `gr'

** Compute counterfactual income: 1980 kid inc / 2010 GDP * 2.5% growth * 1980 GDP
gen kid_inc_grineq = kid_inc / `gdpfw10' * (1 + `gr')^30 * `gdpfw80'
drop kid_inc 
rename kid_inc_grineq kid_inc 

** Make sure percentiles are sorted correctly
sort kid_inc
assert _n == percentile
save kid_marginal, replace
copy kid_marginal.dta kid_marginal_hh_40.dta, replace

** Make sure using 1970 par marginal
copy par_marginal_1970_40.dta par_marginal.dta, replace

*Run mobility with counterfactual income
absmob compute mob, cohorts(1970) copula("copula_base_adjusted") 
copy absmob.dta absmob_1970hh_40.dta, replace

*************************************************************************
** More broadly shared growth counterfactual with age 40
*************************************************************************

** Get 1940 shares of GDP
use marginals_40, clear
keep if cohort == 1940
gen sh40 = kid_inc / `gdpfw80'
keep percentile sh40
tempfile sh40
save `sh40'

** Get 1970 marginal distributions
local max = 100
use marginals_40, clear
keep if cohort == 1970

** Merge on 1940 shares
merge 1:1 percentile using `sh40', assert(3) nogen

** Compute counterfactual kid income - 1940 kids share of 1980 GDP * 2010 GDP
gen kid_inc_shlowlow = sh40 * `gdpfw10'
drop kid_inc 
rename kid_inc_shlowlow kid_inc 

sort kid_inc
assert _n == percentile
keep kid_inc percentile cohort
save kid_marginal, replace
copy kid_marginal.dta kid_marginal_ll_40.dta, replace

** Make sure using 1970 par marginal
copy par_marginal_1970_40.dta par_marginal.dta, replace

*Run mobility with counterfactual income
absmob compute mob, cohorts(1970) copula("copula_base_adjusted") 
copy absmob.dta absmob_1970ll_40.dta, replace

*************************************************************************
** Robustness check: Growth shares instead of levels
*************************************************************************

*************************************************************************
** High GDP growth scenario - 1980 growth shares, counterfactual 2.5% GDP growth, age 30
*************************************************************************

local gdpchange8010 = `gdpfw10' - `gdpfw80'

use marginals, clear

keep if cohort == 1980

** Calculate share of GDP growth
gen gdpshare80 = (kid_inc - par_inc) / `gdpchange8010'

** Compute counterfactual income: parent income + kid share of growth * counterfactual 2.5% growth
gen kid_inc_new = par_inc + gdpshare80 * (1.025^30 *`gdpfw80' - `gdpfw80')
drop kid_inc 
rename kid_inc_new kid_inc 

** Sort percentiles
sort kid_inc
drop percentile
gen percentile = _n

sort kid_inc
assert _n == percentile

keep kid_inc percentile cohort
save kid_marginal, replace
copy kid_marginal.dta kid_marginal_hhgr.dta, replace

** Make sure using 1980 par marginal
copy par_marginal_1980.dta par_marginal.dta, replace

** Run mobility with counterfactual income
absmob compute mob, cohorts(1980) copula("copula_base_adjusted") 
copy absmob.dta absmob_1980hhgr.dta, replace


*************************************************************************
** More broadly shared growth scenario - 1940 growth shares, 1980 GDP growth, age 30
*************************************************************************

local gdpchange4070 = `gdpfw70' - `gdpfw40'

** Calculate ratio of income growth at each percentile to GDP growth for 1940 cohort
use marginals, clear
keep if cohort == 1940
gen gdpshare40 = (kid_inc - par_inc) / `gdpchange4070'
tempfile grsh40
save `grsh40'

** Compute counterfactual income: parent income + 1940 cohort growth share * 1980-2010 GDP growth
use marginals, clear
keep if cohort == 1980
merge 1:1 percentile using `grsh40'
gen kid_inc_new = par_inc + gdpshare40 * `gdpchange8010'

drop kid_inc 
rename kid_inc_new kid_inc 

** Sort percentiles
sort kid_inc
assert _n == percentile
keep kid_inc percentile cohort
save kid_marginal, replace
copy kid_marginal.dta kid_marginal_llgr.dta, replace

** Make sure using 1980 par marginal
copy par_marginal_1980.dta par_marginal.dta, replace

*Run mobility with counterfactual income
absmob compute mob, cohorts(1980) copula("copula_base_adjusted") 
copy absmob.dta absmob_1980llgr.dta, replace


*************************************************************************
** High GDP growth scenario - 1970 growth shares, counterfactual 2.5% GDP growth, age 40
*************************************************************************

local gdpchange8010 = `gdpfw10' - `gdpfw80'

** Calculate GDP growth share by percentile
use marginals_40, clear
keep if cohort == 1970
gen gdpshare70 = (kid_inc - par_inc) / `gdpchange8010'

** Calculate counterfactual income
gen kid_inc_new = par_inc + gdpshare70 * (1.025^30 *`gdpfw80' - `gdpfw80')
drop kid_inc 
rename kid_inc_new kid_inc 

** Sort percentiles
sort kid_inc
drop percentile
gen percentile = _n

sort kid_inc
assert _n == percentile
keep kid_inc percentile cohort
save kid_marginal, replace
copy kid_marginal.dta kid_marginal_hhgr40.dta, replace

** Make sure using 1970 par marginal
copy par_marginal_1970_40.dta par_marginal.dta, replace

*Run mobility with counterfactual income
absmob compute mob, cohorts(1970) copula("copula_base_adjusted") 
copy absmob.dta absmob_1970hhgr40.dta, replace

*************************************************************************
** More broadly shared growth scenario - 1940 growth shares, 1980-2010 observed GDP growth, age 40
*************************************************************************

local gdpchange5080 = `gdpfw80' - `gdpfw50'

** Get 1940 shares of GDP growth
use marginals, clear
keep if cohort == 1940
gen gdpshare40 = (kid_inc - par_inc) / `gdpchange5080'
tempfile grsh40
save `grsh40'

** Calculate counterfactual incomes: 1970 parent income + 1940 growth shares * 1980-2010 GDP growth
use marginals, clear
keep if cohort == 1970
merge 1:1 percentile using `grsh40'
gen kid_inc_new = par_inc + gdpshare40 * `gdpchange8010'

** Sort percentiles
drop kid_inc 
rename kid_inc_new kid_inc 

sort kid_inc
assert _n == percentile
keep kid_inc percentile cohort
save kid_marginal, replace
copy kid_marginal.dta kid_marginal_llgr40.dta, replace

** Make sure using 1970 par marginal
copy par_marginal_1970_40.dta par_marginal.dta, replace

*Run mobility with counterfactual income
absmob compute mob, cohorts(1970) copula("copula_base_adjusted") 
copy absmob.dta absmob_1970llgr40.dta, replace


*************************************************************************
** Statistics on income distribution
*************************************************************************

use marginals, clear

** 10-90 difference **
*1940 cohort
sum kid_inc if percentile == 10 & cohort == 1940
local ki4010 = r(mean)
sum kid_inc if percentile == 90 & cohort == 1940
noi di r(mean) / `ki4010' //4.2513352
noi di r(mean) - `ki4010' //70011

*1980 cohort
sum kid_inc if percentile == 10 & cohort == 1980
local ki8010 = r(mean)
sum kid_inc if percentile == 90 & cohort == 1980
noi di r(mean) / `ki8010' //26.244667
noi di r(mean) - `ki8010' //118347

** 30 year-old - GDP difference **
*1940 cohort
sum kid_inc if cohort == 1940
noi di r(mean) / `gdpfw70' //.691017

*1980 cohort
sum kid_inc if cohort == 1980
noi di r(mean) / `gdpfw10' //.44279039

** Total CPS vs GDP **
noi di `cpstotinc70' / (`gdptot1970'*1000000000) //73%
noi di `cpstotinc10' / (`gdptot2010'*1000000000) //60%

** Total (not per working-age family) GDP growth
*1980 number of working-age families
use workfam_counts, clear
keep if year == 1980
local fams80 = famwork
noi di `fams80' //73376900

*2010 number of working-age families
use workfam_counts, clear
keep if year == 2010
local fams10 = famwork
noi di `fams10' //108546159

use counterfactuals_gdpnums, clear

* Observed 1980-2010 per working-age family growth
assert year[4] == "1980"
assert year[5] == "2010"

noi di (gdpfw[5] / gdpfw[4]) ^ (1/30) //1.0147011

* Observed 1980-2010 total GDP growth
noi di (gdptot[5] / gdptot[4]) ^ (1/30) //1.028032

* 2.5% High GDP growth counterfactual total GDP growth
noi di ((gdpfw[4] * 1.025 ^ 30 * `fams10') / (gdpfw[4] * `fams80' )) ^ (1/30) //1.0384662

* 5% High GDP growth counterfactual total GDP growth
noi di ((gdpfw[4] * 1.05 ^ 30 * `fams10') / (gdpfw[4] * `fams80' )) ^ (1/30) //1.0637947


*************************************************************************
** Save data so that plots can be made 
*************************************************************************
use absmob_1980obs, clear
ren abs_mob abs_mob_1980obs
merge 1:1 parent_percentile using absmob_1940obs, assert(3) nogen
ren abs_mob abs_mob_1940obs 
merge 1:1 parent_percentile using absmob_1980hh, assert(3) nogen
ren abs_mob abs_mob_1980hh 
merge 1:1 parent_percentile using absmob_1980ll, assert(3) nogen
ren abs_mob abs_mob_1980ll
merge 1:1 parent_percentile using absmob_1980gr10, assert(3) nogen
ren abs_mob abs_mob_1980gr1
merge 1:1 parent_percentile using absmob_1980gr20, assert(3) nogen
ren abs_mob abs_mob_1980gr2
merge 1:1 parent_percentile using absmob_1980gr30, assert(3) nogen
ren abs_mob abs_mob_1980gr3
merge 1:1 parent_percentile using absmob_1980gr40, assert(3) nogen
ren abs_mob abs_mob_1980gr4
merge 1:1 parent_percentile using absmob_1980gr50, assert(3) nogen
ren abs_mob abs_mob_1980gr5
merge 1:1 parent_percentile using absmob_1980gr60, assert(3) nogen
ren abs_mob abs_mob_1980gr6
merge 1:1 parent_percentile using absmob_1980gr70, assert(3) nogen
ren abs_mob abs_mob_1980gr7
merge 1:1 parent_percentile using absmob_1980gr80, assert(3) nogen
ren abs_mob abs_mob_1980gr8
merge 1:1 parent_percentile using absmob_1980gr90, assert(3) nogen
ren abs_mob abs_mob_1980gr9
merge 1:1 parent_percentile using absmob_1980gr100, assert(3) nogen
ren abs_mob abs_mob_1980gr10
merge 1:1 parent_percentile using absmob_1980mob, assert(3) nogen
ren abs_mob abs_mob_1980mob
merge 1:1 parent_percentile using absmob_1980imob, assert(3) nogen
ren abs_mob abs_mob_1980imob
merge 1:1 parent_percentile using absmob_1980ll_samp30, assert(3) nogen
ren abs_mob abs_mob_1980ll_samp30
merge 1:1 parent_percentile using absmob_1980ll_cpsincwf, assert(3) nogen
ren abs_mob abs_mob_1980ll_cpsincwf
merge 1:1 parent_percentile using absmob_194040, assert(3) nogen
ren abs_mob abs_mob_1940obs_40
merge 1:1 parent_percentile using absmob_197040, assert(3) nogen
ren abs_mob abs_mob_1970obs_40
merge 1:1 parent_percentile using absmob_1970hh_40, assert(3) nogen
ren abs_mob abs_mob_1970hh_40
merge 1:1 parent_percentile using absmob_1970ll_40, assert(3) nogen
ren abs_mob abs_mob_1970ll_40
merge 1:1 parent_percentile using absmob_1970hhgr40, assert(3) nogen
ren abs_mob abs_mob_1970hhgr_40
merge 1:1 parent_percentile using absmob_1970llgr40, assert(3) nogen
ren abs_mob abs_mob_1970llgr_40
merge 1:1 parent_percentile using absmob_1980hhgr, assert(3) nogen
ren abs_mob abs_mob_1980hhgr
merge 1:1 parent_percentile using absmob_1980llgr, assert(3) nogen
ren abs_mob abs_mob_1980llgr
drop cohort inflection

** Label variables
label var abs_mob_1980obs "Baseline 1980"
label var abs_mob_1940obs "Baseline 1940"
label var abs_mob_1980hh "Higher GDP Growth"
label var abs_mob_1980ll "More Broadly Shared Growth"
label var abs_mob_1980mob "Perfectly Fluid Copula"
label var abs_mob_1980imob "Perfectly Static Copula"
label var abs_mob_1980gr1 "1% Real GDP per fam growth"
label var abs_mob_1980gr2 "2% Real GDP per fam growth"
label var abs_mob_1980gr3 "3% Real GDP per fam growth"
label var abs_mob_1980gr4 "4% Real GDP per fam growth"
label var abs_mob_1980gr5 "5% Real GDP per fam growth"
label var abs_mob_1980gr6 "6% Real GDP per fam growth"
label var abs_mob_1980gr7 "7% Real GDP per fam growth"
label var abs_mob_1980gr8 "8% Real GDP per fam growth"
label var abs_mob_1980gr9 "9% Real GDP per fam growth"
label var abs_mob_1980gr10 "10% Real GDP per fam growth"
label var abs_mob_1980ll_samp30 "Observed 30-yr-old growth, 1940 dist."
label var abs_mob_1980ll_cpsincwf "Observed total CPS income growth, 1940 dist."
label var abs_mob_1970obs_40 "Baseline 1970, age 40"
label var abs_mob_1940obs_40 "Baseline 1940, age 40"
label var abs_mob_1970hh_40 "2.5% GDP growth, unequal dist., age 40"
label var abs_mob_1970ll_40 "Observed growth, 1940 dist., age 40"
label var abs_mob_1970hhgr_40 "2.5% GDP growth, unequal growth dist., age 40"
label var abs_mob_1970llgr_40 "Observed growth, 1940 growth dist., age 40"
label var abs_mob_1980hhgr "2.5% GDP growth, unequal growth dist."
label var abs_mob_1980llgr "Observed growth, 1940 growth dist."
save "counterfactuals", replace

** Make dataset of mean mobility, adjusting for parent zeros
collapse (mean) *

tempfile cfactsum
save `cfactsum', replace

use $results_baseline/parents_frac0, clear
preserve
keep if cohort == 1940
local fzero40 = frac0
restore
keep if cohort == 1980
local fzero80 = frac0

use "$results_robustness/40 vs 40/parents_frac0", clear
preserve
keep if cohort == 1970
local fzero70age40 = frac0
restore
keep if cohort == 1940
local fzero40age40 = frac0

use `cfactsum', clear
foreach v of varlist abs_mob_1980* {
	replace `v' = `v' * (1-`fzero80') + `fzero80'
	}
	
replace abs_mob_1940obs = abs_mob_1940obs * (1-`fzero40') + `fzero40'
	
foreach v of varlist abs_mob_1970* {
	replace `v' = `v' * (1-`fzero70age40') + `fzero70age40'
	}
	
replace abs_mob_1940obs_40 = abs_mob_1940obs_40 * (1-`fzero40age40') + `fzero40age40'
	
save "counterfactuals_summary", replace

