// Computes parental and children's marginal income distributions, as well as absolute mobility, by state
// Gets called by robustness.do, and uses the globals specified therein. 
// If running independently of robustness.do, specify paths in the globals commented out below.

set more off
//global absmob_indir  	"" //Path to folder that will contain the cleaned data
//global absmob_outdir  "" //Path to folder that will contain the results

local compute_parents  true
local compute_kids     true  
local compute_mobility true  
local rescale_states   true  //rescales the state cohort means so that they aggregate to the national mean

local quantiles 100    // other option is: 20
local qtile percentile // other option is: ventile

local start_decade 1940
local end_decade   2010
local cohort_start 1940
local cohort_end   1980
local parent_age_min 16
local parent_age_max 45
local income_age_min 25
local income_age_max 35
local income_age_max_earliest 45
local child_age_min 25
local child_age_max 35
local min_obs 20 // state-cohort marginal coded as missing if fewer than `min_obs' obs

discard
adopath + "sources"

*****************************************************************************

//Make the outdir if it doesn't exist
ssc install confirmdir
confirmdir "$absmob_outdir"
if _rc > 0 { 
	mkdir "$absmob_outdir"
}

if "`compute_parents'" == "true" {

	clear
	gen cohort = .
	gen state = .
	gen `qtile' = .
	gen par_inc = . 
	save "$absmob_outdir/par_marginal.dta", replace	
	
	clear
	gen cohort = .
	gen state = .
	gen double frac0 = .
	save "$absmob_outdir/parents_frac0.dta", replace
	
	u "$absmob_indir/census2010_families.dta", clear
	levelsof statefip, local(states)

	foreach st in `states' {

		* generate representative parent ids for each decade, by state state
		forval census_year = `start_decade' (10) `end_decade' {
			
			use "$absmob_indir/census`census_year'_families.dta", clear 
			gen double rep_id = id
			replace rep_id  = id_spouse  if inctot < inctot_spouse & id_spouse  != .
			replace rep_id  = id_spouse  if inctot == . & inctot_spouse != . & id_spouse  != .		
			replace rep_id  = id_spouse  if inctot_spouse !=. &  inctot == inctot_sp & sex == 1 & id_spouse  != .					
			drop if mi(rep_id)
			gen rep_age = cond(rep_id == id, age, age_spouse)
			gen rep_sex = cond(rep_id == id, sex, sex_spouse)
			local name = "`:label (statefip) `st''"
			gen str7 state_name = "`name'"
			keep if statefip == `st'
			tempfile census`census_year'_families
			save `census`census_year'_families', replace
			
			use "$absmob_indir/census`census_year'_couples.dta", clear 
			gen double rep_id = id
			replace rep_id  = id_spouse  if inctot < inctot_spouse & id_spouse  != .
			replace rep_id  = id_spouse  if inctot == . & inctot_spouse != . & id_spouse  != .		
			replace rep_id  = id_spouse  if inctot_spouse !=. &  inctot == inctot_sp & sex == 1 & id_spouse  != .					
			drop if mi(rep_id)
			gen rep_age = cond(rep_id == id, age, age_spouse)
			gen rep_sex = cond(rep_id == id, sex, sex_spouse)
			local name = "`:label (statefip) `st''"
			gen str7 state_name = "`name'"
			keep if statefip == `st'
			tempfile census`census_year'_couples
			save `census`census_year'_couples', replace
			
		}
		
		* Now create samples for each cohort
		foreach cohort of numlist `cohort_start' (10) `cohort_end' {

			//The "focal" census for a cohort is the census where kids born in a cohort first show up.
			//For example, focal census for 1961, 1969 or 1970 is 1970
			local focal_census = 10*ceil(`cohort' / 10 )
			
			//For each year in which the census was conducted (i.e., for each decade), check whether we need
			//to extract any data from that census to construct the parent sample for this particular cohort.
								
			forval census_year = `start_decade' (10) `end_decade' {
								
				//NOTE: Nothing needs to happen w.r.t par_gender -- 
				//rep. parent is already set to father or mother in the loop at start of this phase, 
				//and all invalid rows have been dropped accordingly
				
				local delta = `census_year' - `cohort'
				
				if `delta' >= 0 {					
					//This is a "Future" census w.r.t the Focal census
					
					use `census`census_year'_families', clear 
					
					//Parents extracted from a "Future" census should adhere to 3 constraints:
					//First, their child should've been born in year = cohort
					keep if age_child == `delta'
					
					//Second, their age (at the time of the census) should lie between income_age_min and income_age_max,
					//with the below exception:					
					if "`census_year'" == "`start_decade'" {
						//Since there's no earlier census to pull records from, we also extract age ranges that 
						//we'd have pulled from a previous census
						local income_age_max_earliest = `parent_age_max' - (`cohort' - `census_year')											
						keep if rep_age >= `income_age_min' & rep_age <= `income_age_max_earliest'
					}
					else {						
						keep if rep_age >= `income_age_min' & rep_age <= `income_age_max'
					}
				
					//Third, their age at the time of the birth of their child (i.e., in year = cohort)
					//should lie between parent_age_min and parent_age_max
					gen par_age_at_childbirth = rep_age - age_child
					keep if par_age_at_childbirth  >= `parent_age_min' & par_age_at_childbirth <= `parent_age_max'
					drop par_age_at_childbirth
				}
				
				else {													
					//This is a "Past" census w.r.t the Focal census
										
					//We don't really know which individuals from the past will go on to have a child by year = 'cohort'.
					//So we can't apply the 1st constraint above. Instead, we assume ALL parents who meet age criteria 
					//go on to have kids.
					
					use `census`census_year'_couples', clear 
									
					//Same as check #2 in the "future" case
					if "`census_year'" == "`start_decade'" {
						//Since there's no earlier census to pull records from, we also extract age ranges that 
						//we'd have pulled from a previous census if it existed
						local income_age_max_earliest = `parent_age_max' - (`cohort' - `census_year')
						keep if rep_age >= `income_age_min' & rep_age <= `income_age_max_earliest'
					}
					else {						
						keep if rep_age >= `income_age_min' & rep_age <= `income_age_max'
					}										
										
					//Same as check #3 in the "future" case (because age_child == delta)
					gen par_age_at_childbirth = rep_age - `delta'
					keep if par_age_at_childbirth  >= `parent_age_min' & par_age_at_childbirth <= `parent_age_max'
					drop par_age_at_childbirth
				}
				
				//These Macros (n_from_focal) will be used to calculate substitution weights later (see note below)
				su rep_age
				local n_from`census_year' = _N
					
				***************
				preserve
				
				use `census`focal_census'_families', clear
				
				local child_age = `focal_census' - `cohort'
				local delta = `focal_census' - `census_year'
				
				//These are the same 3 constraints as above				
				count if age_child == `child_age' & ///
						rep_age >= (`income_age_min' + `delta') & rep_age <= (`income_age_max' + `delta') & ///
						rep_age - `child_age' >= `parent_age_min' & rep_age - `child_age' <= `parent_age_max'
				
				local n_from_focal = r(N)
				
				restore
				***************
				//To construct the parent sample, we need to reweight parents from an older or a newer census 
				//to match the number of parents they represent (substitute) in the focal ("current") census.
				//See the Data section in the paper for an explanation.
				
				gen weights = `n_from_focal' / `n_from`census_year''
				replace weights = 1 if `census_year' == `focal_census'
				replace weights = round(weights*1000000) //weights are meant to be integers
				
				keep year id marst id_spouse rep_id age rep_age rep_sex sex weights statefip state_name famsize age_spouse sex_spouse ///
					nchild incwage incwage_spouse inctot inctot_spouse ftotinc nonwage incwelfr incwelfr_spouse 
				
				tempfile sample_from`census_year'
				save `sample_from`census_year''	
				
				if (`n_from`census_year'' == 0){
					//No rows extracted from this census; pointless to print
					continue
				}				
			} //end foreach census_year
			
			//combine the extracts from each census to create the parent-sample for this cohort
			clear
			forval census_year = `start_decade' (10) `end_decade' {				
				append using `sample_from`census_year''
			}
			tempfile sample_`cohort'
			save `sample_`cohort'', replace

		} //end foreach cohort
		
		*******************END PHASE ************************

		foreach cohort of numlist `cohort_start' (10) `cohort_end' {

			use `sample_`cohort'', clear
			
			//Generate the "income" variable
			capture drop income
			gen income = .
				
			//create new (temporary) variables that will allow us to use rowtotal
			tempvar incwelfr incwelfr_spouse //incssi incssi_spouse
			gen `incwelfr' = -incwelfr
			gen `incwelfr_spouse' = -incwelfr_spouse

			tempvar income1940 income1950 income1960 inctotOnly
				
			//egen `income1960' = rowtotal(inctot inctot_spouse `incwelfr' `incwelfr_spouse' `incssi' `incssi_spouse')
			egen `income1960' = rowtotal(inctot inctot_spouse `incwelfr' `incwelfr_spouse')
			egen `inctotOnly' = rowtotal(inctot inctot_spouse)
				
			gen `income1950' = ftotinc		
			egen `income1940' = rowtotal(incwage incwage_spouse nonwage)	
				
			replace income = `income1940' if year >= 1940 & year < 1950
			replace income = `income1950' if year >= 1950 & year < 1960
										
			replace income = `income1960' if year >= 1960		
			
			drop if income == .
			count
			if r(N) < `min_obs' {
				clear
				set obs 1
				local calculate_frac0_`cohort' false
				gen `qtile' = 99999
				gen par_inc = 99999
				gen statefip = `st'
				gen state_name = ""
			}
			if r(N) >= `min_obs' {

				local calculate_frac0_`cohort' true
				//Scale income by inflator
				preserve	
				use "$absmob_indir/cpirs", clear
				sort year
				keep year rate
				tempfile inflation
				save    `inflation', replace
				keep if year == 2014
				local inflation_rate = rate[1]
				restore
		
				replace year = year - 1 //income refers to previous calendar year
				merge m:1 year using `inflation', assert(match using) keep(match master) nogen
				replace year = year + 1
				replace rate = rate / `inflation_rate'
				replace income = income/rate
				
				//In constructing the IGE copula, parents with income <= 0 were dropped. In other words,
				//parent-income columns correspond only to positive incomes. To adjust for this in our code, 
				//we drop all parents with <= 0 incomes; but keep a record of the fraction of rows dropped,
				//and bring them back in later while computing absolute mobility stats
				local focalCensus = 10*ceil(`cohort'/10)
				
				su income if income > 0 [fw = weights]
				local n_pos_income = r(sum_w)
	
				su income [fw = weights]
				local n_income = r(sum_w)
				
				local frac0_`cohort' =  1 - (`n_pos_income' / `n_income')
				
				keep if income > 0 & weights > 0
				
				if `=_N' <= `min_obs' {
					//Too few rows to compute percentiles. Skip.
					continue
				}
				//Export a sample: 
				//save "$absmob_outdir/imp_par_sample_`cohort'_`st'", replace
				
				if `=_N' < `quantiles'{
					mixtile income `quantiles' `qtile' weights
					keep if `qtile' == int(`qtile') //Exactly 20 (or 100) rows should remain; no merging with zero_incomes necessary
					collapse (mean) par_inc = income (firstnm) statefip state_name, by(`qtile')
				}
				else{					
					fastxtile `qtile' = income [fw=weights], n(`quantiles')
					collapse (mean) par_inc = income (firstnm) statefip state_name, by(`qtile')
				}
				
				//For all missing values, if _n = 1, set value to 0 else, set value to _N-1
				if "`qtile'" == "ventile"    merge 1:1 `qtile' using "$absmob_indir/zero_incomes_ventiles", nogen
				if "`qtile'" == "percentile" merge 1:1 `qtile' using "$absmob_indir/zero_incomes", nogen
				sort `qtile'
				su par_inc
				replace par_inc = cond(`r(min)' < 0, `r(min)' - 0.01, 0) if `qtile' == 1 & mi(par_inc)
				replace par_inc = par_inc[_n-1] if mi(par_inc) & `qtile' > 1
				replace par_inc = round(par_inc)
				
				replace statefip = `st' if statefip == .
				replace state_name = state_name[_n-1] if state_name == "" & _n > 1
			}
			gen cohort = `cohort'
			rename statefip state

			keep state cohort `qtile' par_inc state_name			
			tempfile par_marginal_`st'_`cohort'
			save "`par_marginal_`st'_`cohort''", replace

		} //cohort loop closes

		//combine all cohort-wise marginal incomes into a single file
		use "$absmob_outdir/par_marginal.dta", replace
		foreach cohort of numlist `cohort_start'(10)`cohort_end' {
			//we capture because files for some cohorts may not exist
			capture append using "`par_marginal_`st'_`cohort''" 
		}
		sort cohort state `qtile' 
		order cohort `qtile' state
		save "$absmob_outdir/par_marginal.dta", replace
		
		//Save the fraction of parents with income <= 0 for each cohort		
		keep cohort
		duplicates drop
		gen state = `st'
		gen double frac0 = .
		foreach cohort of numlist `cohort_start'(10)`cohort_end' {
			if "`calculate_frac0_`cohort''" == "true" replace frac0 = `frac0_`cohort'' if cohort == `cohort'
		}
		tempfile parents_frac0_`st'
		save    `parents_frac0_`st''
		use "$absmob_outdir/parents_frac0.dta", clear
		append using `parents_frac0_`st''
		save "$absmob_outdir/parents_frac0.dta", replace
	} //state loop closes
} //compute_parent condition


/** Compute Children's Distributions **/

if "`compute_kids'" == "true" {

	clear
	gen cohort = .
	gen `qtile' = .
	gen kid_inc = . 
	gen str7 state_name = ""
	save "$absmob_outdir/kid_marginal.dta", replace	
	
	foreach year of numlist 1970(10)2010 {
	
		u "$absmob_indir/census`year'_couples.dta", clear 	
		
		//create new (temporary) variables that will allow us to use rowtotal
		tempvar incwelfr incwelfr_spouse
		gen `incwelfr' = -incwelfr
		gen `incwelfr_spouse' = -incwelfr_spouse
			
		egen income = rowtotal(inctot inctot_spouse `incwelfr' `incwelfr_spouse')
	
		drop if income == .
		gen double rep_id = id
		replace rep_id  = id_spouse  if inctot < inctot_spouse & id_spouse  != .
		replace rep_id  = id_spouse  if inctot == . & inctot_spouse != . & id_spouse  != .		
		replace rep_id  = id_spouse  if inctot_spouse !=. &  inctot == inctot_sp & sex == 1 & id_spouse  != .					
		drop if mi(rep_id)
		gen rep_age = cond(rep_id == id, age, age_spouse)
		gen rep_sex = cond(rep_id == id, sex, sex_spouse)
		
		//inflate income
		preserve	
		use "$absmob_indir/cpirs", clear
		sort year
		keep year rate
		tempfile inflation
		save    `inflation', replace
		keep if year == 2014
		local inflation_rate = rate[1]
		restore
		
		replace year = year - 1 //income refers to previous calendar year
		merge m:1 year using `inflation', assert(match using) keep(match master) nogen
		replace year = year + 1
		replace rate = rate / `inflation_rate'
		replace income = income/rate
	
		replace bpl = . if bpl >= 100
		replace bpl_spouse = . if bpl_spouse >= 100
		
		keep 	 if (age >= `child_age_min' & age <= `child_age_max') | (age_spouse >= `child_age_min' & age_spouse <= `child_age_max')
		expand 2 if  age >= `child_age_min' & age <= `child_age_max'  &  age_spouse >= `child_age_min' & age_spouse <= `child_age_max'	
		gen rep_bpl = cond(age >= `child_age_min' & age <= `child_age_max', bpl, bpl_spouse)
	
		bysort id: replace rep_bpl = cond(_n==2, bpl_spouse, bpl)
		//when doubling a row because both spouses are in the age bracket, change bpl in 1 of them
		
		levelsof rep_bpl, local(states)
		
		tempfile working
		save    `working', replace
		
		foreach st in `states' {
			
			use `working', clear
			keep if rep_bpl == `st'
			local name = "`:label (bpl) `st''"
			gen str7 state_name = "`name'"
			rename rep_bpl state

			if `year' == 2010 local weights [pw=hhwt] //the 2010 Census requires sampling weights
			if `year' != 2010 local weights
	
			count
			if r(N) < `quantiles' {
				clear
				set obs 1
				gen `qtile' = 99999
				gen kid_inc = 99999
				gen state = `st'
				gen state_name = ""
			}
			if r(N) >= `quantiles' {							
	
				fastxtile `qtile' = income `weights', n(`quantiles')
				collapse (mean) kid_inc = income (firstnm) state state_name, by(`qtile')
				keep `qtile' kid_inc state state_name
				
				//If cases where consequtive income cutoffs are identical (e.g. if ptile 65 == ptile 66)
				//we end up with missing percentiles using fastxtile. 
				//For all missing values, if _n = 2 or 1, set value to 0 else, set value to _N-1
				if "`qtile'" == "ventile"    merge 1:1 `qtile' using "$absmob_indir/zero_incomes_ventiles", nogen
				if "`qtile'" == "percentile" merge 1:1 `qtile' using "$absmob_indir/zero_incomes", nogen
				
				sort `qtile'
				su kid_inc
				replace kid_inc = cond(`r(min)' < 0, `r(min)' - 0.01, 0) if `qtile' == 1 & mi(kid_inc)
				replace kid_inc = kid_inc[_n-1] if mi(kid_inc) & `qtile' > 1
				qui replace kid_inc = round(kid_inc)

				replace state = `st' if state == .
				replace state_name = state_name[_n-1] if state_name == "" & _n > 1
			}
			local cohort = `year' - 30
			gen cohort = `cohort'
	
			tempfile kid`cohort'
			save    `kid`cohort'', replace
			
			use "$absmob_outdir/kid_marginal.dta", clear
			append using `kid`cohort''
			save "$absmob_outdir/kid_marginal.dta", replace	
		} //st loop closes
	} //year loop closes
} //compute_kids condition

if "`compute_mobility'" == "true" {
	
	capture program drop find_rank
	program define find_rank, rclass
	
		syntax varlist(min=1 max=1), VALue(real)
		local varname `varlist' //because only one value is allowed
		
		sort `varname'
		
		if `value' < `varname'[1] {
			return local index 0
			exit
		}
		
		local j = 1
		while `j' <= _N & `varname'[`j'] < `value'{
			local j = `j' + 1
		}
		
		if `j' > _N{
			return local index _N
			exit
		}
		
		if `j' <= _N & `j' > 1{
			local j = (`j'-1) + ((`value' - `varname'[`j'-1]) / (`varname'[`j'] - `varname'[`j' - 1]))
		}
		return local index `j'
		
	end

	u "$absmob_indir/census2010_families.dta", clear
	levelsof statefip, local(states)

	foreach st in `states' { 
		
		use "$absmob_resultsdir/Baseline/copula_base_adjusted_by_year", clear
		if "`qtile'" == "ventile" {
			forval i = 1/20 {
				local j = 5*`i' - 4
				local k = 5*`i'
				egen newp`i' = rowtotal(p`j'-p`k')
				replace newp`i' = newp`i'/5
			}
			drop p*
			rename newp* p*
			forval i = 1/20 {
				preserve
				local j = 5*`i' - 4
				local k = 5*`i'			
				keep if kid_bin >= `j' & kid_bin <= `k'
				collapse (firstnm) kid_bin (sum) p1-p20 , by(cohort)
				replace kid_bin = `i'
				tempfile temp`i'
				save    `temp`i'', replace
				restore
			}
			clear
			forval i = 1/20 {
				append using `temp`i''
			}
			sort cohort kid_bin
			save "$absmob_indir/copula_ventiles_adjusted_by_year", replace
		}
	
		use "$absmob_outdir/par_marginal", clear
		keep if state == `st'
		keep if cohort >= `cohort_start' & cohort <= `cohort_end'
		drop if `qtile' == 99999 //too few obs for inc dist
		keep `qtile' cohort par_inc state state_name
		count
		if r(N) < `quantiles' continue
		
		tempfile par_temp
		save    `par_temp', replace

		use "$absmob_outdir/kid_marginal", clear
		keep if state == `st'
		keep if cohort >= `cohort_start' & cohort <= `cohort_end'
		drop if `qtile' == 99999 //too few obs for inc dist
		count
		if r(N) < `quantiles' continue

		merge 1:1 state `qtile' cohort using `par_temp', keep(match) nogen
		rename `qtile' kid_bin
		if "`qtile'" == "percentile" merge 1:1 kid_bin cohort using "$absmob_resultsdir/Baseline/copula_base_adjusted_by_year",   keep(match) nogen
		if "`qtile'" == "ventile"    merge 1:1 kid_bin cohort using "$absmob_indir/copula_ventiles_adjusted_by_year", keep(match) nogen
		rename kid_bin `qtile'
	
		gen double inflection = 0 // the kids' income rank at which kid income crosses par income
		gen double abs_mob = 0 // absolute mobility -- fraction of kids earning at least par income
		
		levelsof cohort, local(cohorts)	
		foreach c in `cohorts' {			
			
			preserve
	
			keep if cohort == `c'
			
			forvalues i = 1/`quantiles' {
				
				**For parent income at the i'th percentile (i.e., parent_income[i]),
				**find the index 'j' at which kid_income[j] is at least as high as parent_income[i].
				**Interpolate linearly between `j' and `j+1' if kid_inc[j] < par_inc[i] < kid_inc[j+1]
				
				local parent_income = par_inc[`i']
				find_rank kid_inc, val(`parent_income')
				replace inflection = `r(index)' if _n == `i'
				local base = floor(inflection[`i'])
				local frac = inflection[`i'] - `base'
				
				if `base' == 0 {
					**even the kid at the 0th ventile/percentile earns more than this parent
					replace abs_mob = 1 if _n == `i'
				}
				else if `base' == `quantiles' {
					**even the kid at the 20th ventile/100th percentile doesn't earn as much as this parent
					replace abs_mob = 0 if _n == `i'
				}
				else{
					local colsum = 0
					forvalues j = 1/`base'{
						local colsum = `colsum' + p`i'[`j']
					}
					local j = `base' + 1
					local colsum = `colsum' + (p`i'[`j'] * `frac')
					replace abs_mob = (1 - `colsum') if _n == `i'
				}
			}
			tempfile rank_`c'
			keep state state_name cohort `qtile' inflection abs_mob* 
			save `rank_`c'', replace
			restore
		}
	
		clear
		foreach c in `cohorts' {
			append using `rank_`c''
		}	
		rename abs_mob abs_mob_pos_par		
		rename `qtile' parent_`qtile'
		
		tempfile absmob_`st'
		save    `absmob_`st'', replace
	}
	clear
	foreach st in `states' {
		capture confirm file `absmob_`st''
		if _rc != 0 {
			continue
		}
		else {
			append using `absmob_`st''
		}
	}
	lab var state "State FIPS code"
	keep if !mi(state)
	save "$absmob_outdir/absmob", replace
}

if "`rescale_states'" == "true" {

	// baseline results
	use "$absmob_resultsdir/Baseline/figure_input_data", clear
	bys cohort: egen cohort_mean_pos_par = mean(abs_mob_pos_par)
	g cohort_mean_base = (1-frac0)*cohort_mean_pos_par + frac0
	collapse (mean) cohort_mean_base, by(cohort)
	keep cohort cohort_mean_base
	tempfile base
	save `base'
	
	// Get state populations of kid age for average of state means weighted by population
	u "$absmob_indir/census2010_families.dta", clear
	levelsof statefip, local(states)
	clear
	gen state_pop = .
	label var state_pop "Frac of US `child_age_min'-`child_age_max' year olds living in state"
	gen state = .
	gen year = .
	save "$absmob_resultsdir/Robustness/States/state_pop", replace
	foreach year of numlist 1940(10)2010 {
		foreach state in `states' {
			use "$absmob_indir/census`year'", clear
			if `year'==2010 local weight [aw=hhwt]
			if `year'< 2010 local weight
			su if age >= `child_age_min' & age <= `child_age_max' & statefip==`state' `weight', mean
			local num = r(N)
			su if age >= `child_age_min' & age <= `child_age_max' `weight', mean
			local denom = r(N)
			clear
			set obs 1
			gen year = `year'
			gen state = `state'
			gen state_pop = `num'/`denom'
			tempfile temp
			save    `temp', replace
			use "$absmob_resultsdir/Robustness/States/state_pop", clear
			append using `temp'
			save "$absmob_resultsdir/Robustness/States/state_pop", replace
		}
	} 
	use "$absmob_resultsdir/Robustness/States/state_pop", clear
	replace state_pop = state_pop*100000
	gen cohort = year-30
	keep if cohort >= `cohort_start' & cohort <= `cohort_end'
	tempfile pop
	save    `pop', replace 
	
	// state results
	use "$absmob_resultsdir/Robustness/States/absmob", clear
	collapse (mean) abs_mob_pos_par (first) state_name , by(state cohort)
	merge 1:1 state cohort using "$absmob_resultsdir/Robustness/States/parents_frac0", nogen keep(master match)
	g cohort_mean_state = (1-frac0)*abs_mob_pos_par + frac0
	drop abs_mob frac0
	tempfile state
	save    `state'
		
	// aggregate to national cohorts and merge baseline series
	merge 1:1 state cohort using `pop', nogen keepusing(state_pop)
	collapse (mean) cohort_mean* [w=state_pop], by(cohort)
	
	merge 1:1 cohort using `base', nogen keep(match)
	gen diff = cohort_mean_base - cohort_mean_state
	drop cohort_mean_base
	tempfile diff
	save    `diff', replace
	
	use `state', clear
	merge m:1 cohort using `diff', nogen
	
	gen cohort_mean_state_rescaled = cohort_mean_state + diff
	sort cohort state
	save "$absmob_resultsdir/Robustness/States/state_rescaled_means", replace
}
