//Computes absolute mobility using post-tax and post-transfer incomes

* Edit these globals to reflect your local paths 
global absmob_indir "" //Path to folder containing cleaned input data (See data_clean in README)
global absmob_resultsdir "" //Should be the same as specified in Robustness.do
global absmob_sourcesdir "" //The path to the folder containing the downloaded source code (e.g. sources.do)

*Currently, the Transfer series is disabled because we cannot share the underlying data. See README
//global transfersroot "$dropboxroot/data/rawdata/transfers mean values by bins"


**********************************************************
* PART 0: Settings		  							     		 *
**********************************************************
global absmob_outdir "$absmob_resultsdir/Robustness/tax&transfer"
adopath + "$absmob_sourcesdir"

global start_year 1940
global end_year 1984
global transfers_start_year = 1967
global transfers_end_year = 2014

global base_year 2014 //the year to which incomes have been inflated to by absmob
global inflator "cpirs"
global adj true //adjust for parent zeroes

global batchsize 100000 //How many obs to send to taxsim at once
if "`c(os)'" == "Windows"{
		//Computations are done locally, so we can use a larger batchsize
		global batchsize 1000000
}
		
global age_of_comparison 30
global par_sample_frac //(Currently not used). Frac of parent-sample sent to taxsim.
global inctype incmix //income measure to use

//For taxsimlocal to work, taxsim9 needs to be in the env.path and not adopath
//TODO: compile a version for mac
confirmdir "$absmob_outdir"
if _rc > 0 { 
	mkdir "$absmob_outdir"
}
cd "$absmob_outdir"

*copy taxsim's server-side binary to working directory
if "`c(os)'" == "Windows"{
	copy "$absmob_indir/taxsim9.exe" "taxsim9.exe", replace
}

set more off

local do_kids_phase1 true	//Send kids' income samples to taxsim
local do_kids_phase2 true	//Compute post-tax marginals for kids
local do_pars_phase1 true	//Send parents' income samples to taxsim
local do_pars_phase2 true	//Compute post-tax marginals for parents

local do_transfers_kids f 	//Include transfers in post-tax income for kids
local do_transfers_pars f 	//Include transfers in post-tax income for kids
local do_absmob true 		//Compute the final mobility statistic after tax

local scale_transfers_by 1  //Multiply transfers by this number before adding to income
local do_taxsim_adjustment false //Scale MTR taxes to bring them in line with Taxsim estimates
local ratio_tsim2mtr_path "$absmob_outdir/ratio_tsim2mtr_1960" //path to the ratio file, used if the flag above is true.

**********************************************************
* PART 1: Programs										 *
**********************************************************
//A program to generate input variables that taxsim requires
capture program drop prepare_for_taxsim
program define prepare_for_taxsim, rclass
	
	args taxyear	
	
	assert year == `taxyear'
		
	//Assume depchild = nchild -- likely to be true for people in the age range we're considering
	//taxsim9 halts if # dependents > 15
	gen depchild = nchild
	replace depchild = 15 if depchild > 15 
	gen depx = depchild

	*state -- can only be 1-51; or 0 if you don't want state taxes		
	gen state = 0

	/*
	marst -- IPUMS variable for marital status
	1 - Married, spouse present
	2 - Married, spouse absent
    3 - Separated
    4 - Divorced
    5 - Widowed
    6 - Never married/single
	
	mstat -- TAXSIM input variable for marital(filing) status. 
	1 - single 
	2 - married
	3 - head of household
	*/
	
	gen mstat = 1
	replace mstat = 2 if marst == 1 | marst == 2
	replace mstat = 3 if (depchild > 0 & mstat == 1) 

	*agex -- no. of taxpayers who're 65+
	gen agex = cond(age >= 65, 1, 0)
	replace agex = cond(!mi(age_sp) & age_sp >= 65, agex + 1, agex)
	
	*For simplicity's sake, assign all income to pwages and 0 to spouse. 
	*Doesn't seem to make a different to TAXSIM
	gen pwages = income
	gen swages = 0
	
	*weights is not used by TAXSIM but is useful when calculating marginals
	rename id pid
	capture rename id_spouse pid_spouse
	capture gen rep_age = $age_of_comparison //only for kids.
	keep year* pid* mstat weights state depchild depx pwages swages agex rep_age incwelf*
end

//A program to adjust incomes to a particular year by a given index
//Assumes the variable `income' and `year' are defined
capture program drop scale_income
program define scale_income, rclass

	args index_file income_var from_year to_year
	
	preserve
	use "`index_file'", clear
	keep year rate
	gen from_rate = rate if year == `from_year'
	su from_rate
	local from_rate = `r(max)'
	gen to_rate = rate if year == `to_year'
	su to_rate
	local to_rate = `r(max)'
	restore
	replace `income_var' = (`income_var' * `to_rate') / `from_rate'
	
end

/*Send data (with the right variables) to taxsim to calculate taxes
*Originally, this program batched observations and sent them to NBER's taxsim server to estimate taxes.
*The request would hang if ~200000 observations were sent at a time; and therefore, we batched them before sending.
*sample_frac allows you to send a random sub-sample (of size sample_frac).
*But in the current version, we run taxsim *LOCALLY*, using `taxsimlocal'; so the program's name is a bit of a misnomer.
*/
capture program drop send_to_taxsim
program define send_to_taxsim, rclass
	args batch_size prefix sample_frac

	if "`sample_frac'" == "" {
		local sample_frac = 1
	}
	
	gen rando = floor(runiform() / `sample_frac')
	keep if rando == 0
	
	gen id = _n
	gen batch_id = int(id/`batch_size')
	local max_batch = int(_N/`batch_size')
	
	//send to taxsim
	set more off
	forvalues batch = 0 / `max_batch'{
		preserve
		keep if batch_id == `batch'
		
		if "`c(os)'" == "Windows"{
			//taxsimlocal runs the taxsim computation locally
			taxsimlocal, replace
		}
		else{
			//Send data to taxsim server -- takes much longer
			taxsim9, replace
		}
		
		save "$absmob_outdir/`prefix'output_`batch'", replace
		restore
	}

	//merge all batches into a single output file
	use "$absmob_outdir/`prefix'output_0", clear
	forvalues batch = 1/`max_batch'{
		append using "`prefix'output_`batch'"
	}

end

capture program drop absmob //Erase any loaded program definition

**********************************************************
* PART 2a: Send kid samples to Taxsim					 *
**********************************************************

if "`do_kids_phase1'" == "true"{
	
	capture erase "$absmob_outdir/kid_marginal.dta"
	
	**Generate pre-tax incomes 	
	absmob compute kid, cohorts($start_year / $end_year) income(measure($inctype)) debug("true") adj

	**Reshape data to create input variables for tax-sim 
	forvalues yr = $start_year / $end_year {
		use "$absmob_outdir/kid_sample_`yr'", clear
		rename wtsupp weights
		local taxyear = `yr' + $age_of_comparison
		prepare_for_taxsim `taxyear'
		
		*Incomes in samples are in terms of base_year, but TAXSIM requires
		*them to be in terms of taxyear.
		local taxyear_inf = `taxyear' - 1
		scale_income "$absmob_indir/$inflator" "pwages" $base_year `taxyear_inf'
	
		save "$absmob_outdir/kid_input_`yr'", replace
	}

	**Combine all input into a single file
	use "$absmob_outdir/kid_input_$start_year", clear
	local next_year = $start_year + 1
	forvalues yr = `next_year' / $end_year{
		append using "$absmob_outdir/kid_input_`yr'"
	}
	save "$absmob_outdir/kid_input", replace

	**This program does the following:
	**1. Chunks data into optimally-sized batches for TAXSIM to process
	**2. Sends them to taxsim and waits for the results
	**3. Combines all the batches' results
	**4. REPLACES data in memory with the output from taxsim

	send_to_taxsim $batchsize "kid_"
	save "$absmob_outdir/kid_output", replace
}

**********************************************************
* PART 2b: generate post-tax incomes for kids			 *
**********************************************************

if "`do_kids_phase2'" == "true"{

	*calculate transfers *before* subtracting tax liability
	if "`do_transfers_kids'" == "true" {		
		local kid_start = $start_year + $age_of_comparison
		local kid_end = $end_year + $age_of_comparison
		* produces a dataset describing the in-kind transfers of each observation
		do "$dropboxroot/sources/transfers.do" cps `kid_start' `kid_end'
	}
	
	use "$absmob_outdir/kid_output", clear
	rename pwages income
	
	if "`do_transfers_kids'" == "true" {
		egen long couple_id = rowmin(pid pid_spouse)
	    merge m:1 year couple_id using "$absmob_outdir/cps_with_transfers", nogen
		
		*Add cash transfers like AFDC and SSI (SSI is already included in INCWELFR at the clean up stage)
		egen transfer = rowtotal(incwelfr incwelfr_spouse) 
		*For 0 income households, we can't obtain tax credits from taxsim; so we add them from the Transfers data
		replace transfer = transfer + hh_totben if income <= 0 & !mi(hh_totben)
		*For +ve income households, we add non-credit, non-cash transfers from the Transfers data (Fox et al)
		replace transfer = transfer + hh_totben_nocredits if income > 0 & !mi(hh_totben_nocredits)
		replace income = income + (`scale_transfers_by' * transfer) if !mi(transfer)
	}
	*Now subtract federal tax liability
	replace income = income - fiitax if !mi(fiitax)
	*save a copy for debugging
	save "$absmob_outdir/kid_output", replace
	
	capture erase "$absmob_outdir/kid_marginal.dta"

	forvalues cohort = $start_year / $end_year{

		preserve
		local taxyear = `cohort' + $age_of_comparison
		keep if year == `taxyear'
		
		*Incomes in output are in terms of taxyear, 
		*convert them to base_year.
		local taxyear_inf = `taxyear' - 1
		scale_income "$absmob_indir/$inflator" "income" `taxyear_inf' $base_year
		
		fastxtile percentile = income [pw=weights], n(100)
		collapse (mean) kid_inc = income, by(percentile)
		keep percentile kid_inc

		//If cases where consequtive income cutoffs are identical (e.g. if ptile 65 == ptile 66)
		//we end up with missing percentiles using fastxtile. Fix this.
		//For all missing values, set kid_inc to previous percentile's kid_inc. Unless the missing
		//value is at the start; in which case, set it to 0.01 less than the current lowest value
		merge 1:1 percentile using "$absmob_indir/zero_incomes", nogen			
		sort percentile
		su kid_inc 
		replace kid_inc = cond(`r(min)' < 0, `r(min)' - 0.01, 0) if percentile == 1 & mi(kid_inc)
		replace kid_inc = kid_inc[_n-1] if mi(kid_inc) & percentile > 1
		replace kid_inc = round(kid_inc)
		gen cohort = `cohort'
		
		if `cohort' != $start_year{
			append using "$absmob_outdir/kid_marginal"
		}
		save "$absmob_outdir/kid_marginal", replace	
		restore	
	}
}
**********************************************************
* PART 3a: Send parent samples to Taxsim				 *
**********************************************************

if $start_year < 1960 local ts_start_year = 1960
if $start_year >= 1960 local ts_start_year = $start_year

if "`do_pars_phase1'" == "true"{

	capture erase "$absmob_outdir/par_marginal.dta"
	capture erase "$absmob_outdir/par_marginal_mtr.dta"
	capture erase "$absmob_outdir/parents_frac0_post1960"
	
	absmob compute par, cohorts(`ts_start_year' / $end_year) income(measure($inctype)) debug(true) adj
	
	** Save frac0 under a different name for years after 1960, 
	** because it's going to get overwritten when we run absmob with MTR for years before 1960
	use "$absmob_outdir/parents_frac0", clear
	save "$absmob_outdir/parents_frac0_post1960", replace
	
	**Reshape data to create input variables for tax-sim
	forvalues yr = `ts_start_year' / $end_year {
		
		use "$absmob_outdir/par_sample_`yr'", clear
		
		//append zeroes if they exist; we'll exclude them again just before
		//it's time to send to taxsim
		append using "$absmob_outdir/par_sample_`yr'_zeroes"
		local taxyear = `yr'
		
		rename year year_census //The census from which this obs was taken.
		gen year = `taxyear' // Prepare_for_taxsim assumes year = yr for which taxes are being computed
		
		prepare_for_taxsim `taxyear'
		
		*Incomes in samples are in terms of base_year, but TAXSIM requires
		*them to be in terms of taxyear.
		local taxyear_inf = `taxyear' - 1
		scale_income "$absmob_indir/$inflator" "pwages" $base_year `taxyear_inf'
		save "$absmob_outdir/par_input_`yr'", replace
	}

	**Combine all input into a single file
	use "$absmob_outdir/par_input_`ts_start_year'", clear
	local next_year = `ts_start_year' + 1
	forvalues yr = `next_year' / $end_year{
		append using "$absmob_outdir/par_input_`yr'"
	}
	save "$absmob_outdir/par_input", replace

	**send to TAXSIM and save the results
	send_to_taxsim $batchsize "par_" $par_sample_frac
	save "$absmob_outdir/par_output", replace
}
**********************************************************
* PART 3b: generate post-tax incomes for parents		 *
**********************************************************

if "`do_pars_phase2'" == "true"{

	capture erase "$absmob_outdir/par_marginal.dta"
	capture erase "$absmob_outdir/par_marginal_mtr.dta"
	
	if $start_year < 1960 {
		**For years before 1960, we approximate par-marginal using MTR
		absmob compute par, cohorts($start_year / 1959) income(measure($inctype) taxby(mtr)) adj
		use "$absmob_outdir/par_marginal.dta", clear
		
		if "`do_taxsim_adjustment'" == "true"{
			//Assumes there's a file describing the ratios to scale each percentile by
			merge m:1 percentile using "`ratio_tsim2mtr_path'"
			replace par_inc = par_inc * ratio_tsim2mtr if cohort < 1960
			save, replace
		}
		
		save "$absmob_outdir/par_marginal_mtr.dta"
		capture erase "$absmob_outdir/par_marginal.dta"
		
		if $end_year >= 1960{
			**There SHOULD be a parents_frac0_post1960 produced from the run in phase1,
			**(which is simply the parents_frac0 file renamed for years after 1960). 
			**Combine the two into a single file now.
			use "$absmob_outdir/parents_frac0", clear
			append using "$absmob_outdir/parents_frac0_post1960"
			sort cohort
			save "$absmob_outdir/parents_frac0", replace
		}
	}
	
	** saves the file census_with_transfers.dta in $absmob_outdir, transfer data is available 1967 onward
	if "`do_transfers_pars'" == "true" { 		
		do "$dropboxroot/sources/transfers.do" census $start_year $end_year 
		
		//use "$absmob_outdir/par_output", clear
		//calculate_transfers //adds columns describing the transfer amount; doesn't add transfers to income
	}
	
	
	use "$absmob_outdir/par_output", clear
	rename pwages income
	
	if "`do_transfers_pars'" == "true" {
		egen long couple_id = rowmin(pid pid_spouse)
		gen zeroinc = income <= 0
		merge m:1 year year_census couple_id using "$absmob_outdir/census_with_transfers", nogen
		*Add cash transfers, like AFDC and SSI (SSI is already included in INCWELFR at the clean up stage)
		egen transfer = rowtotal(incwelfr incwelfr_spouse) 
		*For 0 income households, we can't obtain tax credits from taxsim; so we add them from the Transfers data
		replace transfer = transfer + hh_totben if income <= 0 & !mi(hh_totben)
		*For +ve income households, we add non-credit, non-cash transfers from the Transfers data (Fox et al)
		replace transfer = transfer + hh_totben_nocredits if income > 0 & !mi(hh_totben_nocredits)
		replace income = income + (`scale_transfers_by' * transfer) if !mi(transfer)
	}
	*subtract federal tax liability
	replace income = income - fiitax if !mi(fiitax)
	*save a copy for debugging
	save "$absmob_outdir/par_output", replace
	
	forvalues cohort = `ts_start_year' / $end_year{

		preserve
		keep if year == `cohort'
		
		*Incomes in output are in terms of taxyear (= cohort), 
		*convert them to base_year.
		local taxyear_inf = `cohort' - 1
		scale_income "$absmob_indir/$inflator" "income" `taxyear_inf' $base_year
		
		if "`do_transfers_pars'" == "true"{	
			//recompute frac0 because it might've changed after transfers.
			su income if income > 0 [fw = weights]
			local n_pos_income = r(sum_w)
			su income [fw = weights]
			local n_income = r(sum_w)
			local frac0_`cohort' =  1 - (`n_pos_income' / `n_income')
		}
		
		//TODO: match this with adj?
		keep if income > 0

		fastxtile percentile = income [fw=weights], n(100)
		collapse (mean) par_inc = income, by(percentile)
		keep percentile par_inc

		//If cases where consequtive income cutoffs are identical (e.g. if ptile 65 == ptile 66)
		//we end up with missing percentiles using fastxtile. Fix this.
		//For all missing values, set kid_inc to previous percentile's kid_inc. Unless the missing
		//value is at the start; in which case, set it to 0.01 less than the current lowest value
		merge 1:1 percentile using "$absmob_indir/zero_incomes", nogen			
		sort percentile
		su par_inc
		replace par_inc = cond(`r(min)' < 0, `r(min)' - 0.01, 0) if percentile == 1 & mi(par_inc)
		replace par_inc = par_inc[_n-1] if mi(par_inc) & percentile > 1
		replace par_inc = round(par_inc)		
		gen cohort = `cohort'
		
		if `cohort' != `ts_start_year'{
			append using "$absmob_outdir/par_marginal"
		}
		save "$absmob_outdir/par_marginal", replace	
		restore
	}
	
	use "$absmob_outdir/par_marginal", clear
	capture append using "$absmob_outdir/par_marginal_mtr"
	sort cohort percentile
	save "$absmob_outdir/par_marginal", replace
	
	**update frac0 if needed
	if "`do_transfers_pars'" == "true"{	
		use "$absmob_outdir/parents_frac0", clear
		forvalues cohort = `ts_start_year' / $end_year{
				replace frac0 = `frac0_`cohort'' if cohort == `cohort'
		}
		saveold "$absmob_outdir/parents_frac0", replace version(12)
	}
	
}

**********************************************************
* PART 3: Compute Mobility		 						 *
**********************************************************
if "`do_absmob'" == "true"{
	absmob compute mob, cohorts($start_year/$end_year) adj
}
